import random


RANGE = (-0.01, 0.01)

class FakeFloat(float):
    def __init__(self, number):
        self.number = number

    def __new__(self, number):
        return super(FakeFloat, self).__new__(self, number)

    def __add__(self, other):
        plus = random.uniform(*RANGE)

        if self.__class__ == other.__class__:
            return FakeFloat(self.number + float(other.number) + plus)
        else:
            return FakeFloat(self.number) + FakeFloat(other + plus)




import sys
import random
if sys.version_info >= (3,):
    import builtins
else:
    import __builtin__ as builtins


from destruction.FakeFloat import FakeFloat
builtins.float = FakeFloat

from destruction.FakeMath import FakeMath
sys.modules['math'] = FakeMath()



import sys
import random
import math as actual_math


RANGE = (-0.01, 0.01)

class FakeMath:
    def __init__(self):
        self.custom_pi = actual_math.pi
        self.custom_e = actual_math.e

    @property
    def pi(self):
        self.custom_pi += random.uniform(*RANGE)
        return self.custom_pi

    @property
    def e(self):
        self.custom_e += random.uniform(*RANGE)
        return self.custom_e

    def __getattr__(self, name):
        """
        We don't want to break the entire math module. So if we get anything
        other than `e` or `pi`, let's give it to the original module.
        """
        return getattr(actual_math, name)

FakeMath.__doc__ = actual_math.__doc__



import codecs
import setuptools
import os
import sys

here = os.path.abspath(os.path.dirname(__file__))

setuptools.setup(
    name='destruction',

    version='0.1.2',

    description='Destroy Python programs with a simple import.',

    url='https://github.com/adtac/destruction',

    author='Adhityaa Chandrasekar',
    author_email='c.adhityaa@gmail.com',

    license='MIT',

    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],

    packages=['destruction'],
)
